@@ -7,7 +7,7 @@
 #pragma once
 
 #include <powerdevilaction.h>
-#include <powerdevilbackendinterface.h>
+#include <powerdevilbrightnesslogic.h>
 
 namespace PowerDevil::BundledActions
 {
@@ -29,6 +29,8 @@ public:
 
     int brightness() const;
     int brightnessMax() const;
+    int brightnessMin() const;
+    int knownSafeBrightnessMin() const;
     int brightnessSteps() const;
 
 public Q_SLOTS:
@@ -41,16 +43,18 @@ public Q_SLOTS:
     void setBrightnessSilent(int percent);
 
 private Q_SLOTS:
-    void onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &brightnessInfo);
+    void onBrightnessChangedFromController(const BrightnessLogic::BrightnessInfo &brightnessInfo);
 
 Q_SIGNALS:
     void brightnessChanged(int value);
     void brightnessMaxChanged(int valueMax);
+    void brightnessMinChanged(int valueMin);
 
 private:
     int brightnessPercent(float value) const;
 
     int m_defaultValue = -1;
+    BrightnessLogic::BrightnessInfo m_lastBrightnessInfo;
 };
 
 }
