@@ -84,15 +84,18 @@ HandleButtonEvents::HandleButtonEvents(QObject *parent)
             });
 
     if (!core()->lidController()->isLidClosed()) {
-        m_oldKeyboardBrightness = backend()->keyboardBrightness();
+        m_oldKeyboardBrightness = core()->keyboardBrightnessController()->brightness();
     }
-    connect(backend(), &PowerDevil::BackendInterface::keyboardBrightnessChanged, this, [this](const BrightnessLogic::BrightnessInfo &brightnessInfo) {
-        // By the time the lid close is processed, the backend brightness will already be updated.
-        // That's why we track the brightness here as long as the lid is open.
-        if (!core()->lidController()->isLidClosed()) {
-            m_oldKeyboardBrightness = brightnessInfo.value;
-        }
-    });
+    connect(core()->keyboardBrightnessController(),
+            &KeyboardBrightnessController::brightnessInfoChanged,
+            this,
+            [this](const BrightnessLogic::BrightnessInfo &brightnessInfo) {
+                // By the time the lid close is processed, the backend brightness will already be updated.
+                // That's why we track the brightness here as long as the lid is open.
+                if (!core()->lidController()->isLidClosed()) {
+                    m_oldKeyboardBrightness = brightnessInfo.value;
+                }
+            });
 }
 
 HandleButtonEvents::~HandleButtonEvents()
@@ -120,7 +123,7 @@ void HandleButtonEvents::onLidClosedChanged(bool closed)
 {
     if (closed) {
         if (m_oldKeyboardBrightness.has_value()) {
-            backend()->setKeyboardBrightness(0);
+            core()->keyboardBrightnessController()->setBrightness(0);
         }
 
         if (!m_screenConfiguration) {
@@ -138,7 +141,7 @@ void HandleButtonEvents::onLidClosedChanged(bool closed)
         // When we restore the keyboard brightness before waking up, we shouldn't conflict
         // with dimdisplay or dpms also messing with the keyboard.
         if (m_oldKeyboardBrightness.has_value() && m_oldKeyboardBrightness > 0) {
-            backend()->setKeyboardBrightness(m_oldKeyboardBrightness.value());
+            core()->keyboardBrightnessController()->setBrightness(m_oldKeyboardBrightness.value());
         }
 
         // In this case, let's send a wakeup event
