@@ -70,6 +70,7 @@ Core::Core(QObject *parent)
     discreteGpuJob->start();
 
     readChargeThreshold();
+    readBatteryConservationMode();
 }
 
 Core::~Core()
@@ -79,23 +80,21 @@ Core::~Core()
     unloadAllActiveActions();
 }
 
-void Core::loadCore(BackendInterface *backend)
+void Core::loadCore()
 {
-    m_backend = backend;
-
     m_suspendController = std::make_unique<SuspendController>();
     m_batteryController = std::make_unique<BatteryController>();
     m_lidController = std::make_unique<LidController>();
+    m_keyboardBrightnessController = std::make_unique<KeyboardBrightnessController>();
+    m_screenBrightnessController = std::make_unique<ScreenBrightnessController>();
 
-    // Async backend init - so that KDED gets a bit of a speed up
-    qCDebug(POWERDEVIL) << "Core loaded, initializing backend";
-    connect(m_backend, &BackendInterface::backendReady, this, &Core::onBackendReady);
-    m_backend->init();
+    connect(m_screenBrightnessController.get(), &ScreenBrightnessController::detectionFinished, this, &Core::onControllersReady);
+    m_screenBrightnessController->detectDisplays();
 }
 
-void Core::onBackendReady()
+void Core::onControllersReady()
 {
-    qCDebug(POWERDEVIL) << "Backend ready, KDE Power Management system initialized";
+    qCDebug(POWERDEVIL) << "Controllers ready, KDE Power Management system initialized";
 
     const bool isMobile = Kirigami::Platform::TabletModeWatcher::self()->isTabletMode();
     const bool isVM = PowerDevil::PowerManagement::instance()->isVirtualMachine();
@@ -272,6 +271,7 @@ void Core::reparseConfiguration()
     }
 
     readChargeThreshold();
+    readBatteryConservationMode();
 }
 
 QString Core::currentProfile() const
@@ -955,9 +955,27 @@ void Core::readChargeThreshold()
     job->start();
 }
 
-BackendInterface *Core::backend()
+void Core::readBatteryConservationMode()
 {
-    return m_backend;
+    KAuth::Action action(QStringLiteral("org.kde.powerdevil.chargethresholdhelper.getconservationmode"));
+    action.setHelperId(QStringLiteral("org.kde.powerdevil.chargethresholdhelper"));
+    KAuth::ExecuteJob *job = action.execute();
+    connect(job, &KJob::result, this, [this, job] {
+        if (job->error()) {
+            qCWarning(POWERDEVIL) << "org.kde.powerdevil.chargethresholdhelper.getconservationmode failed" << job->errorText();
+            return;
+        }
+
+        const auto data = job->data();
+        const bool enabled = data.value(QStringLiteral("batteryConservationModeEnabled")).toBool();
+        if (m_batteryConservationModeEnabled != enabled) {
+            m_batteryConservationModeEnabled = enabled;
+            Q_EMIT batteryConservationModeChanged(enabled);
+        }
+
+        qCDebug(POWERDEVIL) << "Battery conservation mode is" << (enabled ? "enabled" : "disabled");
+    });
+    job->start();
 }
 
 SuspendController *Core::suspendController()
@@ -1004,6 +1022,11 @@ bool Core::hasDualGpu() const
     return m_hasDualGpu;
 }
 
+bool Core::isBatteryConservationModeEnabled() const
+{
+    return m_batteryConservationModeEnabled;
+}
+
 int Core::chargeStartThreshold() const
 {
     return m_chargeStartThreshold;
@@ -1147,6 +1170,16 @@ void Core::timerfdEventHandler()
     // send it away
     QDBusConnection::sessionBus().call(msg, QDBus::NoBlock);
 }
+
+KeyboardBrightnessController *Core::keyboardBrightnessController()
+{
+    return m_keyboardBrightnessController.get();
+}
+
+ScreenBrightnessController *Core::screenBrightnessController()
+{
+    return m_screenBrightnessController.get();
+}
 }
 
 #include "moc_powerdevilcore.cpp"
